"lmom.test.nor" <-
function(data) {
   lmom <- lmom.ub(data)
   para <- parnor(lmom)
   cat("NORMAL DISTRIBUTION PARAMETERS\n")
   str(para)
   lmompara <- lmomnor(para)
   Q50 <- quanor(0.5,para)
   cat(c("Computed median=",Q50,"\n"),sep="")
   P50 <- cdfnor(Q50,para)
   cat(c("Nonexceedance of computed median=",P50,"\n"),sep="")
   lmom.diff(lmompara,lmom)
}

